@@ -12,13 +12,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import json
 import logging
 import netaddr
 import netifaces
 import os
 import subprocess
 import sys
+import yaml
 
 from osc_lib.i18n import _
 
@@ -304,8 +304,8 @@ def _validate_no_ip_change():
             os.path.expanduser(os_net_config_file)):
         return
     try:
-        with open(os_net_config_file) as f:
-            network_config = json.loads(f.read())
+        with open(os_net_config_file, 'r') as f:
+            network_config = yaml.safe_load(f)
         ctlplane = [i for i in network_config.get('network_config', [])
                     if i['name'] == 'br-ctlplane'][0]
     except ValueError:
@@ -315,7 +315,10 @@ def _validate_no_ip_change():
         # Nothing to check if br-ctlplane wasn't configured
         return
     existing_ip = ctlplane['addresses'][0]['ip_netmask']
-    if existing_ip != CONF.local_ip:
+    conf_netaddr = netaddr.IPNetwork(CONF.local_ip)
+    existing_netaddr = netaddr.IPNetwork(existing_ip)
+    if (conf_netaddr != existing_netaddr
+            or conf_netaddr.ip != existing_netaddr.ip):
         message = _('Changing the local_ip is not allowed.  Existing IP: '
                     '{0}, Configured IP: {1}').format(
                         existing_ip, CONF.local_ip)
@@ -399,11 +402,6 @@ def _validate_architecure_options():
         LOG.error(_('Undercloud configuration validation failed: %s'), message)
         raise FailedValidation(message)
 
-    def _validate_ppc64le_exclusive_opts(error_callback):
-        if 'ipxe_enabled' in CONF and CONF['ipxe_enabled']:
-            error_callback(_('Currently iPXE boot isn\'t supported with '
-                             'ppc64le systems but is enabled'))
-
     def _validate_additional_architectures(error_callback):
         for arch in CONF['additional_architectures']:
             if arch not in constants.ADDITIONAL_ARCHITECTURES:
@@ -416,8 +414,6 @@ def _validate_architecure_options():
                                  '%(all_architectures)s') % params)
 
     _validate_additional_architectures(error_handler)
-    if 'ppc64le' in CONF['additional_architectures']:
-        _validate_ppc64le_exclusive_opts(error_handler)
 
 
 def _checking_status(item):
